============
Front Matter
============

Information about the *tinyshar* project.

Project Homepage
================

*tinyshar* is hosted on `GitHub <https://github.com/kshpytsya/tinyshar>`_.

Releases and project status are available on Pypi at https://pypi.org/project/tinyshar/.

The most recent published version of this documentation should be at https://tinyshar-docs.surge.sh/.

Installation
============

Install released versions of *tinyshar* from the Python package index with `pip <http://pypi.python.org/pypi/pip>`_ or a similar tool::

    pip install tinyshar

Bugs
====

Bugs and feature enhancements to *tinyshar* should be reported on `here <https://github.com/kshpytsya/tinyshar/issues>`_.
